Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Func ¶
type Func[A, R any] struct { // contains filtered or unexported fields }
Func is a function that takes a single argument of type A and returns a single result of type R along with an error. If an error is returned, it becomes a no-op.
Click to show internal directories.
Click to hide internal directories.